# The Atomic Coordinates of an Amorphous Carbon Block

The file with the basename `atomic_coords.xyz`, located in the same directory as
the current README file, stores the atomic coordinates of a model of a $5 \times
5 \times 1 \ \text{nm}^3$ large block of amorphous carbon. These atomic
coordinates were originally calculated by Ricolleau *et al.* for their paper
linked [here](https://doi.org/10.1063/1.4831669). See the supplementary
materials of said paper for all the original atomic coordinate data files that
they generated.

Elsewhere, we use the aforementioned file `atomic_coords.xyz` to generate a $25
\times 25 \times 1 \ \text{nm}^3$ large superblock of amorphous carbon, that is
subsequently truncated.